def android_increment_version(bump_type, version)
  bump_version_map = { 'major' => 0, 'minor' => 1, 'patch' => 2 }

  android_set_version_code(gradle_file: ENV['GRADLE_FILE_PATH'])
  if bump_type
    version_index_bump = bump_version_map[bump_type]

    major, minor, patch =
      android_get_version_name(gradle_file: './android/app/build.gradle').split('.').map(&:to_i)
    version_name =
      if version_index_bump === 0
        "#{major + 1}.0.0"
      elsif version_index_bump === 1
        "#{major}.#{minor + 1}.0"
      else
        "#{major}.#{minor}.#{patch + 1}"
      end

    android_set_version_name(gradle_file: ENV['GRADLE_FILE_PATH'], version_name: version_name)
  elsif version
    android_set_version_name(gradle_file: ENV['GRADLE_FILE_PATH'], version_name: version)
  end
end

def android_build_app(task)
  gradle(print_command: !is_ci, print_command_output: !is_ci, task: task, project_dir: 'android/')
end

def android_upload_app(package_name, bundle_type)
  native_symbols_path =
    File.expand_path(
      "../android/app/build/intermediates/merged_native_libs/#{bundle_type}/out/lib/",
    )
  native_symbols_zip_name = 'native-debug-symbols.zip'
  mapping_path = File.expand_path(native_symbols_zip_name)

  File.delete(mapping_path) if File.exist?(mapping_path)
  zip_file = ZipFileGenerator.new(native_symbols_path, mapping_path)
  zip_file.write

  supply(
    # json_key: './fastlane/google_play.json',
    package_name: package_name,
    skip_upload_apk: true,
    track: 'internal',
    # TODO: Enable proguards mapping file
    # mapping_paths: [
    #   "./android/app/build/outputs/mapping/#{bundle_type}/mapping.txt",
    #   mapping_path,
    # ],
  )
end
