def ios_increment_version(bump_type, version)
  increment_build_number(xcodeproj: ENV['XCODEPROJ_PATH'])

  if bump_type
    increment_version_number(xcodeproj: ENV['XCODEPROJ_PATH'], bump_type: bump_type)
  elsif version
    increment_version_number(xcodeproj: ENV['XCODEPROJ_PATH'], version_number: version)
  end
end

def ios_authenticate_and_bump_version(app_identifier)
  if is_ci
    if File.exist? File.expand_path("~/Library/Keychains/#{ENV['KEYCHAIN_NAME']}-db")
      delete_keychain(name: ENV['KEYCHAIN_NAME'])
    end
    create_keychain(
      name: ENV['KEYCHAIN_NAME'],
      password: ENV['MATCH_PASSWORD'],
      unlock: false,
      timeout: 0,
    )
  end

  api_key =
    app_store_connect_api_key(
      # key_id: 'key_id',
      issuer_id: 'issuer_id',
      # key_filepath: './fastlane/AuthKey.p8',
      duration: 1200,
      in_house: false,
    )

  match(
    app_identifier: app_identifier,
    type: 'appstore',
    readonly: true,
    api_key: api_key,
    keychain_name: is_ci ? ENV['KEYCHAIN_NAME'] : nil,
    keychain_password: is_ci ? ENV['MATCH_PASSWORD'] : nil,
    # Variable for git auth when using CI, i.e. Github Actions
    # git_basic_authorization:
    #   ENV['MATCH_GIT_BASIC_AUTHORIZATION'] &&
    #     Base64.strict_encode64(ENV['MATCH_GIT_BASIC_AUTHORIZATION']),
  )
end

def ios_build_app(scheme)
  gym(
    workspace: ENV['XCWORKSPACE_PATH'],
    scheme: scheme,
    silent: is_ci,
    include_bitcode: true,
    include_symbols: true,
    export_method: 'app-store',
    export_options: {
      provisioningProfiles: {
        '<%- project.package %>' => 'match AppStore <%- project.package %>',
      },
    },
  )

  upload_to_testflight(skip_waiting_for_build_processing: true, expire_previous_builds: true)

  if is_ci
    if File.exist? File.expand_path("~/Library/Keychains/#{ENV['KEYCHAIN_NAME']}-db")
      delete_keychain(name: ENV['KEYCHAIN_NAME'])
    end
  end
end
